@@ -3,6 +3,10 @@
 #
 # BibleTime will be installed to /usr/local by default (see CMAKE_INSTALL_PREFIX below).
 
+if [ "$(uname)" == "Darwin" ]; then
+    # OSX/homebrew
+    export CMAKE_PREFIX_PATH=/usr/local/opt/qt5/lib/cmake/
+fi
 
 if [ ! -d build ]; then mkdir build; fi
 cd build
