@@ -2,21 +2,27 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
-#include "backend/keys/cswordtreekey.h"
+#include "cswordtreekey.h"
 
 #include <QDebug>
 #include <QTextCodec>
-#include "backend/drivers/cswordbookmoduleinfo.h"
+#include "../../util/btassert.h"
+#include "../drivers/cswordbookmoduleinfo.h"
 
 
 CSwordTreeKey::CSwordTreeKey( const CSwordTreeKey& k ) : CSwordKey(k), TreeKeyIdx(k) {}
 
-CSwordTreeKey::CSwordTreeKey( const TreeKeyIdx *k, CSwordModuleInfo* module ) : CSwordKey(module), TreeKeyIdx(*k) {}
+CSwordTreeKey::CSwordTreeKey(const TreeKeyIdx *k,
+                             const CSwordModuleInfo *module)
+    : CSwordKey(module), TreeKeyIdx(*k)
+{
+    // Intentionally empty
+}
 
 CSwordTreeKey* CSwordTreeKey::copy() const {
     return new CSwordTreeKey(*this);
@@ -25,7 +31,7 @@ CSwordTreeKey* CSwordTreeKey::copy() const {
 /** Sets the key of this instance */
 QString CSwordTreeKey::key() const {
     //return getTextUnicode();
-    Q_ASSERT(m_module);
+    BT_ASSERT(m_module);
     if (m_module->isUnicode()) {
         return QString::fromUtf8(getText());
     }
@@ -38,20 +44,20 @@ const char * CSwordTreeKey::rawKey() const {
     return getText();
 }
 
-bool CSwordTreeKey::key( const QString& newKey ) {
+bool CSwordTreeKey::setKey(const QString &newKey) {
     //return key( newKey.toLocal8Bit().constData() );
     //return key(m_module->getTextCodec()->fromUnicode(newKey).constData());
-    Q_ASSERT(m_module);
+    BT_ASSERT(m_module);
     if (m_module->isUnicode()) {
-        return key(newKey.toUtf8().constData());
+        return setKey(newKey.toUtf8().constData());
     }
     else {
-        return key((const char*)cp1252Codec()->fromUnicode(newKey));
+        return setKey(cp1252Codec()->fromUnicode(newKey).constData());
     }
 }
 
-bool CSwordTreeKey::key( const char* newKey ) {
-    Q_ASSERT(newKey);
+bool CSwordTreeKey::setKey(const char *newKey) {
+    BT_ASSERT(newKey);
 
     if (newKey) {
         TreeKeyIdx::operator = (newKey);
@@ -60,13 +66,13 @@ bool CSwordTreeKey::key( const char* newKey ) {
         root();
     }
 
-    return !Error();
+    return !popError();
 }
 
 QString CSwordTreeKey::getLocalNameUnicode() {
     //return m_module->getTextCodec()->toUnicode(getLocalName());
     //Only UTF-8 and latin1 are legal Sword module encodings
-    Q_ASSERT(m_module);
+    BT_ASSERT(m_module);
     if (m_module->isUnicode()) {
         return QString::fromUtf8(getLocalName());
     }
@@ -75,21 +81,21 @@ QString CSwordTreeKey::getLocalNameUnicode() {
     }
 }
 
-CSwordModuleInfo* CSwordTreeKey::module( CSwordModuleInfo* const newModule ) {
-    if (newModule && (newModule != m_module) && (newModule->type() == CSwordModuleInfo::GenericBook) ) {
-        m_module = newModule;
+void CSwordTreeKey::setModule(const CSwordModuleInfo *newModule) {
+    BT_ASSERT(newModule);
+    if (m_module == newModule) return;
+    BT_ASSERT(newModule->type() == CSwordModuleInfo::GenericBook);
 
-        const QString oldKey = key();
+    m_module = newModule;
 
-        CSwordBookModuleInfo* newBook = dynamic_cast<CSwordBookModuleInfo*>(newModule);
-        copyFrom( *(newBook->tree()) );
+    const QString oldKey = key();
 
-        key(oldKey); //try to restore our old key
+    const CSwordBookModuleInfo *newBook = dynamic_cast<const CSwordBookModuleInfo*>(newModule);
+    copyFrom( *(newBook->tree()) );
 
-        //set the key to the root node
-        root();
-        firstChild();
-    }
+    setKey(oldKey); //try to restore our old key
 
-    return m_module;
+    //set the key to the root node
+    root();
+    firstChild();
 }
