@@ -2,61 +2,37 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
-#include "backend/managers/btstringmgr.h"
+#include "btstringmgr.h"
+
+#include <cstring>
+#include <QString>
+#include "../../util/btassert.h"
+#include "../../util/macros.h"
 
 
-char* BTStringMgr::upperUTF8(char* text, unsigned int maxlen) const {
-    const int max = (maxlen > 0) ? maxlen : strlen(text);
+namespace {
 
-    if (isUtf8(text)) {
-        strncpy(text, (const char*)QString::fromUtf8(text).toUpper().toUtf8(), max);
-
-        return text;
-    }
-    else {
-        char* ret = text;
-
-        while (*text) {
-            *text = toupper(*text);
-            text++;
-        }
-
-        return ret;
-    }
-
-    return text;
-}
-
-char* BTStringMgr::upperLatin1(char* text, unsigned int /*max*/) const {
-    char* ret = text;
-
-    while (*text) {
-        *text = toupper(*text);
-        text++;
-    }
-
-    return ret;
-}
-
-bool BTStringMgr::supportsUnicode() const {
-    return true;
-}
-
-bool BTStringMgr::isUtf8(const char *buf) const {
+/** CODE TAKEN FROM KDELIBS 3.2, which is licensed under the LGPL 2.
+*
+* This code was taken from KStringHandler, which is part of the KDE libraries.
+*
+* This function checks whether a string is utf8 or not.
+* It was taken from kdelibs so we do not depend on KDE 3.2.
+*/
+bool isUtf8(const char * buf) {
     int i, n;
-    register unsigned char c;
+    unsigned char c;
     bool gotone = false;
 
 #define F 0   /* character never appears in text */
 #define T 1   /* character appears in plain ASCII text */
 #define I 2   /* character appears in ISO-8859 text */
 #define X 3   /* character appears in non-ISO extended ASCII (Mac, IBM PC) */
-
     static const unsigned char text_chars[256] = {
         /*                  BEL BS HT LF    FF CR    */
         F, F, F, F, F, F, F, T, T, T, T, F, T, T, F, F,  /* 0x0X */
@@ -78,6 +54,9 @@ bool BTStringMgr::isUtf8(const char *buf) const {
         I, I, I, I, I, I, I, I, I, I, I, I, I, I, I, I,  /* 0xeX */
         I, I, I, I, I, I, I, I, I, I, I, I, I, I, I, I   /* 0xfX */
     };
+    #undef F
+    #undef I
+    #undef X
 
     /* *ulen = 0; */
 
@@ -90,6 +69,7 @@ bool BTStringMgr::isUtf8(const char *buf) const {
 
             if (text_chars[c] != T)
                 return false;
+    #undef T
 
         }
         else if ((c & 0x40) == 0) { /* 10xxxxxx never 1st byte */
@@ -134,7 +114,45 @@ done:
     return gotone;   /* don't claim it's UTF-8 if it's all 7-bit */
 }
 
-#undef F
-#undef T
-#undef I
-#undef X
+} // anonymous namespace
+
+char * BtStringMgr::upperUTF8(char * text, unsigned int maxlen) const {
+    size_t max = (maxlen > 0u) ? maxlen : strlen(text);
+
+    if (LIKELY(max > 1u)) {
+        max--;
+        if (isUtf8(text)) {
+            strncpy(text, QString::fromUtf8(text).toUpper().toUtf8().constData(), max);
+        }
+        else {
+            strncpy(text, QString::fromLatin1(text).toUpper().toLatin1().constData(), max);
+        }
+        text[max] = '\0';
+    } else if (max == 1u) {
+        text[0u] = '\0';
+    } else {
+        BT_ASSERT(max == 0u);
+    }
+
+    return text;
+}
+
+char * BtStringMgr::upperLatin1(char * text, unsigned int maxlen) const {
+    size_t max = (maxlen > 0u) ? maxlen : strlen(text);
+
+    if (LIKELY(max > 1u)) {
+        max--;
+        strncpy(text, QString::fromLatin1(text).toUpper().toLatin1().constData(), max);
+        text[max] = '\0';
+    } else if (max == 1u) {
+        text[0u] = '\0';
+    } else {
+        BT_ASSERT(max == 0u);
+    }
+
+    return text;
+}
+
+bool BtStringMgr::supportsUnicode() const {
+    return true;
+}
