@@ -1,43 +1,42 @@
+
 /*********
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
-#include "backend/managers/clanguagemgr.h"
+#include "clanguagemgr.h"
 
-#include "backend/drivers/cswordmoduleinfo.h"
-#include "backend/managers/cswordbackend.h"
-#include "util/cpointers.h"
-
-
-CLanguageMgr::Language::Language() {}
-
-CLanguageMgr::Language::Language(const Language& l) {
-    m_abbrev = l.m_abbrev;
-    m_englishName = l.m_englishName;
-    m_translatedName = l.m_translatedName;
-    m_altAbbrevs = l.m_altAbbrevs;
-}
-
-CLanguageMgr::Language::Language( const QString& abbrev, const QString& name, const QString& translatedName, const QStringList& altAbbrevs ) {
-    m_abbrev = abbrev;
-    m_englishName = name;
-    m_translatedName = translatedName;
-    m_altAbbrevs =  altAbbrevs;
-}
-
-CLanguageMgr::Language::~Language() {
-}
+#include "../drivers/cswordmoduleinfo.h"
+#include "cswordbackend.h"
 
 
 /****************************************************/
 /******************** CLanguageMgr ******************/
 /****************************************************/
-CLanguageMgr::CLanguageMgr() : m_langMap() {
+
+CLanguageMgr *CLanguageMgr::m_instance = nullptr;
+
+void CLanguageMgr::destroyInstance() {
+    delete m_instance;
+    m_instance = nullptr;
+}
+
+CLanguageMgr *CLanguageMgr::instance() {
+    if (m_instance == nullptr) {
+        m_instance = new CLanguageMgr();
+    }
+
+    return m_instance;
+}
+
+CLanguageMgr::CLanguageMgr()
+    : m_defaultLanguage("", "", QString::null)
+    , m_langMap()
+{
     m_availableModulesCache.moduleCount = 0;
     init();
 }
@@ -50,23 +49,24 @@ CLanguageMgr::~CLanguageMgr() {
 }
 
 const CLanguageMgr::LangMap& CLanguageMgr::availableLanguages() {
-    QList<CSwordModuleInfo*> mods = CPointers::backend()->moduleList();
+    QList<CSwordModuleInfo*> const & mods = CSwordBackend::instance()->moduleList();
 
-    if ( m_availableModulesCache.moduleCount != (unsigned int)mods.count() ) { //we have to refill the cached map
+    // Do we have to refill the cached map?
+    if (m_availableModulesCache.moduleCount != mods.count()) {
         m_availableModulesCache.availableLanguages.clear();
         m_availableModulesCache.moduleCount = mods.count();
 
         //collect the languages abbrevs of all modules
         QStringList abbrevs;
 
-        foreach (const CSwordModuleInfo* mod,  mods) {
-            if (!abbrevs.contains(mod->module()->Lang())) {
-                abbrevs.append(mod->module()->Lang());
-            }
+        Q_FOREACH(const CSwordModuleInfo * const mod,  mods) {
+            auto & m = mod->module();
+            if (!abbrevs.contains(m.getLanguage()))
+                abbrevs.append(m.getLanguage());
         }
 
         //now create a map of available langs
-        foreach ( QString abbrev, abbrevs ) {
+        Q_FOREACH(QString const & abbrev, abbrevs) {
             const Language* const lang = languageForAbbrev(abbrev);
 
             if (lang->isValid()) {
@@ -87,9 +87,9 @@ const CLanguageMgr::Language* CLanguageMgr::languageForAbbrev( const QString& ab
     if (it != m_langMap.constEnd()) return *it; //Language is already here
 
     //try to search in the alternative abbrevs
-    foreach (const Language* lang, m_langList ) {
-        if (lang->alternativeAbbrevs().contains(abbrev)) return lang;
-    }
+    Q_FOREACH(const Language * const lang, m_langList)
+        if (lang->alternativeAbbrevs().contains(abbrev))
+            return lang;
 
     // Invalid lang used by a modules, create a new language using the abbrev
     Language* newLang = new Language(abbrev, abbrev, abbrev); //return a language which holds the valid abbrev
@@ -98,26 +98,15 @@ const CLanguageMgr::Language* CLanguageMgr::languageForAbbrev( const QString& ab
     return newLang;
 }
 
-const CLanguageMgr::Language* CLanguageMgr::languageForName( const QString& name ) const {
-    foreach ( const Language* lang, m_langList ) {
-        if (lang->name() == name) return lang;
-    }
-    return &m_defaultLanguage;//invalid language
-}
-
 const CLanguageMgr::Language* CLanguageMgr::languageForTranslatedName( const QString& name ) const {
-    foreach ( const Language* lang, m_langList ) {
-        if (lang->translatedName() == name) return lang;
-    }
+    Q_FOREACH(const Language * const lang, m_langList)
+        if (lang->translatedName() == name)
+            return lang;
     return &m_defaultLanguage; //invalid language
 }
 
 void CLanguageMgr::init() {
 
-    // The main() sets string literal codec to utf8:
-    // QTextCodec::setCodecForTr(QTextCodec::codecForName("UTF-8"));
-    // The language names include escape sequences \uxxxx
-
     //if we've already inserted all items we do not proceed
     if (m_langMap.count() > 0) return;
 
@@ -427,7 +416,7 @@ void CLanguageMgr::init() {
     //: Language name pt
     m_langList.append( new Language("pt", "Portuguese", QObject::tr("Portuguese")) );
     //: Language name pt_BR
-    m_langList.append( new Language("pt_BR", "Brasilian Portuguese", QObject::tr("Brasilian Portuguese")) );//added by ourself
+    m_langList.append( new Language("pt_BR", "Brazilian Portuguese", QObject::tr("Brazilian Portuguese")) );//added by ourself
     //  m_langList.append( new Language("qu", "Quechua", QObject::tr("Quechua")) );
     //: Language name qut
     m_langList.append( new Language("qut", "Quich\u00e9, West Central", QObject::tr("Quich\u00e9, West Central")) );
@@ -537,7 +526,6 @@ void CLanguageMgr::init() {
     //: Language name zu
     m_langList.append( new Language("zu", "Zulu", QObject::tr("Zulu")) );
 
-    foreach (Language* lang, m_langList) {
+    Q_FOREACH(Language * const lang, m_langList)
         m_langMap.insert( lang->abbrev(), lang);
-    }
 }
