@@ -1,8 +1,10 @@
 /*********
 *
+* In the name of the Father, and of the Son, and of the Holy Spirit.
+*
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2011 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -13,18 +15,21 @@
 #include <QDialog>
 
 class QDialogButtonBox;
+class QLabel;
 class QTabWidget;
 class QUrl;
-class QWebView;
+class BtWebEngineView;
 
 class BtAboutDialog: public QDialog {
         Q_OBJECT
     public:
-        BtAboutDialog(QWidget *parent = 0, Qt::WindowFlags wflags = Qt::Dialog);
-        ~BtAboutDialog();
+        BtAboutDialog(QWidget *parent = nullptr, Qt::WindowFlags wflags = Qt::Dialog);
+
+    protected:
+        void resizeEvent(QResizeEvent* event) override;
 
     private:
-        void initTab(QWebView *&tab);
+        void initTab(BtWebEngineView *&tab);
 
         void retranslateUi();
         void retranslateBtTab();
@@ -38,12 +43,14 @@ class BtAboutDialog: public QDialog {
 
     private:
         QTabWidget *m_tabWidget;
-            QWebView *m_bibletimeTab;
-            QWebView *m_contributorsTab;
-            QWebView *m_swordTab;
-            QWebView *m_qtTab;
-            QWebView *m_licenceTab;
+        BtWebEngineView *m_bibletimeTab;
+        BtWebEngineView *m_contributorsTab;
+        BtWebEngineView *m_swordTab;
+        BtWebEngineView *m_qtTab;
+        BtWebEngineView *m_licenceTab;
         QDialogButtonBox *m_buttonBox;
+        QLabel *m_iconLabel;
+        QLabel *m_versionLabel;
 };
 
 #endif
