@@ -1,8 +1,10 @@
 /*********
 *
+* In the name of the Father, and of the Son, and of the Holy Spirit.
+*
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2011 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -11,6 +13,7 @@
 #define INFODISPLAYCROSSREFRENDERING_H
 
 #include "backend/rendering/chtmlexportrendering.h"
+#include "backend/config/btconfig.h"
 
 
 namespace InfoDisplay {
@@ -20,14 +23,14 @@ class CrossRefRendering : public Rendering::CHTMLExportRendering {
         friend class CInfoDisplay;
 
         CrossRefRendering(
-            const DisplayOptions &displayOptions = CBTConfig::getDisplayOptionDefaults(),
-            const FilterOptions &filterOptions = CBTConfig::getFilterOptionDefaults()
+            const DisplayOptions &displayOptions = btConfig().getDisplayOptions(),
+            const FilterOptions &filterOptions = btConfig().getFilterOptions()
         );
 
-        virtual const QString entryLink(const KeyTreeItem &item,
-                                        const CSwordModuleInfo *module);
+        QString entryLink(const KeyTreeItem &item,
+                          const CSwordModuleInfo *module) override;
 
-        virtual const QString finishText( const QString&, KeyTree& tree );
+        QString finishText(const QString &text, const KeyTree &tree) override;
 };
 
 
