@@ -1,8 +1,10 @@
 /*********
 *
+* In the name of the Father, and of the Son, and of the Holy Spirit.
+*
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2011 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -22,7 +24,7 @@ class BtHtmlJsObject: public QObject {
 
     public:
         BtHtmlJsObject(BtHtmlReadDisplay* display);
-        ~BtHtmlJsObject() {}
+
         void moveToAnchor(const QString& anchor);
         void clearPrevAttribute();
 
