@@ -1,8 +1,10 @@
 /*********
 *
+* In the name of the Father, and of the Son, and of the Holy Spirit.
+*
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -29,14 +31,10 @@ class BtToolBarPopupAction : public QWidgetAction {
 // return the QMenu object so a popup menu can be constructed
         QMenu* popupMenu() const;
 
-// Function to catch the Shortcut event and emit the triggered signal
-        virtual bool event(QEvent* e);
-
-    signals:
-        void triggered();
+        bool event(QEvent* e) override;
 
     protected:
-        QWidget* createWidget(QWidget* parent);
+        QWidget* createWidget(QWidget* parent) override;
 
     private slots:
 
