@@ -1,8 +1,10 @@
 /*********
 *
+* In the name of the Father, and of the Son, and of the Holy Spirit.
+*
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2011 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -39,8 +41,6 @@ class BtWindowModuleChooser {
                               CDisplayWindow *parentWindow)
                 : m_window(parentWindow), m_moduleType (moduleType) {}
 
-        virtual ~BtWindowModuleChooser() {}
-
         /**
         * The backend module list was updated, module list and widgets must be updated.
         * This expects that the window module list has already been updated, so
