@@ -1,8 +1,10 @@
 /*********
 *
+* In the name of the Father, and of the Son, and of the Holy Spirit.
+*
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -28,38 +30,35 @@ class CCommentaryReadWindow : public CLexiconReadWindow  {
         */
         static void insertKeyboardActions( BtActionCollection* const a );
 
-        CCommentaryReadWindow(QList<CSwordModuleInfo*> modules, CMDIArea* parent);
-        /**
-        * Store the settings of this window in the given CProfileWindow object.
-        */
-        virtual void storeProfileSettings( Profile::CProfileWindow* profileWindow );
-        /**
-        * Store the settings of this window in the given profile window.
-        */
-        virtual void applyProfileSettings( Profile::CProfileWindow* profileWindow );
-        virtual bool syncAllowed() const;
+        inline CCommentaryReadWindow(const QList<CSwordModuleInfo *> & modules, CMDIArea * parent)
+            : CLexiconReadWindow(modules, parent) {}
 
-    public slots: // Public slots
+        CSwordModuleInfo::ModuleType moduleType() const override
+        { return CSwordModuleInfo::Commentary; }
+
+        void storeProfileSettings(QString const & windowGroup) const override;
+        void applyProfileSettings(const QString & windowGroup) override;
+        bool syncAllowed() const override;
+
+    public slots:
         void nextBook();
         void previousBook();
         void nextChapter();
         void previousChapter();
         void nextVerse();
         void previousVerse();
-        /**
-        * Reimplementation to handle the keychooser refresh.
-        */
-        virtual void reload(CSwordBackend::SetupChangedReason);
+        void reload(CSwordBackend::SetupChangedReason) override;
 
     protected:
-        virtual void initActions();
-        virtual void initToolbars();
+        void initActions() override;
+        void initToolbars() override;
+        void setupMainWindowToolBars() override;
 
     private:
         QAction* m_syncButton;
         CSwordVerseKey* verseKey();
     protected:
-        virtual void setupPopupMenu();
+        void setupPopupMenu() override;
 };
 
 #endif
