@@ -1,8 +1,10 @@
 /*********
 *
+* In the name of the Father, and of the Son, and of the Holy Spirit.
+*
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -12,6 +14,7 @@
 
 #include "frontend/keychooser/ckeychooser.h"
 
+#include "backend/keys/cswordtreekey.h"
 #include "frontend/keychooser/ckeychooserwidget.h"
 
 
@@ -20,9 +23,9 @@ class TreeKeyIdx;
 }
 class CSwordBookModuleInfo;
 class CSwordKey;
-class CSwordTreeKey;
 class QTreeWidget;
 class QTreeWidgetItem;
+class BTHistory;
 
 /** The keychooser implementation for books.
   * @author The BibleTime team
@@ -30,48 +33,43 @@ class QTreeWidgetItem;
 class CBookTreeChooser : public CKeyChooser {
         Q_OBJECT
     public:
-        CBookTreeChooser(QList<CSwordModuleInfo*> modules, CSwordKey *key = 0, QWidget *parent = 0);
-        ~CBookTreeChooser();
-        /**
-        * Refreshes the content.
-        */
-        virtual void refreshContent();
-        /**
-        * Sets another module to this keychooser
-        */
-        virtual void setModules(const QList<CSwordModuleInfo*>& modules, const bool refresh = true);
-        /**
-        * Returns the key of this keychooser.
-        */
-        virtual CSwordKey* key();
-        /**
-        * Sets a new key to this keychooser
-        */
-        virtual void setKey(CSwordKey*);
+        CBookTreeChooser(const BtConstModuleList &modules,
+                         BTHistory *history, CSwordKey *key = nullptr,
+                         QWidget *parent = nullptr);
+
+        void refreshContent() override;
+
+        void setModules(const BtConstModuleList &modules,
+                        bool refresh = true) override;
+
+        inline CSwordKey *key() override {
+            return m_key;
+        }
+
+        void setKey(CSwordKey *key) override;
+
+
         void setKey(CSwordKey*, const bool emitSinal);
 
     public slots: // Public slots
-        virtual void updateKey( CSwordKey* );
-        /**
-        * Reimplementation to handle tree creation on show.
-        */
-        virtual void show();
+        void updateKey( CSwordKey* ) override;
 
+        void doShow();
 
     protected: // Protected methods
         /**
         * Creates the first level of the tree structure.
         */
         void setupTree();
-        virtual void adjustFont();
+        void adjustFont() override;
         void addKeyChildren(CSwordTreeKey* key, QTreeWidgetItem* item);
 
     protected slots: // Protected slots
         void itemActivated( QTreeWidgetItem* item );
-        void setKey(QString& newKey);
+        void setKey(const QString & newKey) override;
 
     private:
-        QList<CSwordBookModuleInfo*> m_modules;
+        QList<const CSwordBookModuleInfo*> m_modules;
         CSwordTreeKey* m_key;
         QTreeWidget* m_treeView;
 };
