@@ -2,38 +2,43 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2011 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
 #include "frontend/keychooser/versekeychooser/btversekeymenu.h"
 
-#include <QDebug>
 #include <QMenu>
 #include <QMouseEvent>
 #include <QTimerEvent>
+#include "util/btconnect.h"
 
 
 BtVerseKeyMenu::BtVerseKeyMenu(QWidget* parent)
-        : QMenu(parent),
-        m_timerId(0),
-        m_firstClickLock(true) {
-    qDebug() << "BtVerseKeyMenu::BtVerseKeyMenu";
-    QObject::connect(this, SIGNAL(aboutToShow()), this, SLOT(startFirstClickDelayTimer()));
+        : QMenu(parent)
+        , m_timerId(0)
+        , m_firstClickLock(true)
+{
+    BT_CONNECT(this, SIGNAL(aboutToShow()),
+               this, SLOT(startFirstClickDelayTimer()));
 }
 
 void BtVerseKeyMenu::startFirstClickDelayTimer() {
-    //qDebug() << "BtVerseKeyMenu::startFirstClickDelayTimer";
     m_firstClickLock = true;
-    killTimer(m_timerId);
+    if (m_timerId) {
+        killTimer(m_timerId);
+        m_timerId = 0;
+    }
     m_timerId = startTimer(300);
 }
 
 void BtVerseKeyMenu::timerEvent(QTimerEvent* e) {
     if (e->timerId() == m_timerId) {
-        //qDebug() << "BtVerseKeyMenu::timerEvent";
-        killTimer(m_timerId);
+        if (m_timerId) {
+            killTimer(m_timerId);
+            m_timerId = 0;
+        }
         m_firstClickLock = false;
     }
     else {
@@ -42,8 +47,6 @@ void BtVerseKeyMenu::timerEvent(QTimerEvent* e) {
 }
 
 void BtVerseKeyMenu::mouseReleaseEvent(QMouseEvent* e) {
-    //qDebug() << "BtVerseKeyMenu::mouseReleaseEvent";
     if (m_firstClickLock) return;
-    //qDebug() << "BtVerseKeyMenu::mouseReleaseEvent 2";
     QMenu::mouseReleaseEvent(e);
 }
