@@ -1,8 +1,10 @@
 /*********
 *
+* In the name of the Father, and of the Son, and of the Holy Spirit.
+*
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2011 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -26,11 +28,10 @@ class BtVerseKeyMenu : public QMenu {
         Q_OBJECT
     public:
         BtVerseKeyMenu(QWidget* parent);
-        ~BtVerseKeyMenu() {}
     protected:
-        virtual void mouseReleaseEvent(QMouseEvent* event);
+        void mouseReleaseEvent(QMouseEvent* event) override;
         /** Frees the mouse button release after the delay has elapsed.*/
-        virtual void timerEvent(QTimerEvent* event);
+        void timerEvent(QTimerEvent* event) override;
     private slots:
         /** Starts the delay timer for the first mouse button release.*/
         void startFirstClickDelayTimer();
