@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -14,11 +14,13 @@
 #include <QDesktopWidget>
 #include <QDialog>
 #include <QDialogButtonBox>
+#include <QtGlobal>
 #include <QVBoxLayout>
 #include "backend/drivers/cswordmoduleinfo.h"
 #include "frontend/searchdialog/analysis/csearchanalysisscene.h"
 #include "frontend/searchdialog/analysis/csearchanalysisview.h"
-#include "util/dialogutil.h"
+#include "frontend/messagedialog.h"
+#include "util/btconnect.h"
 
 
 namespace Search {
@@ -26,20 +28,21 @@ namespace Search {
 static const int DIALOG_HEIGHT = 400;
 static const int DIALOG_BORDER = 30;
 
-CSearchAnalysisDialog::CSearchAnalysisDialog( QList<CSwordModuleInfo*> modules, QWidget* parentDialog )
-        : QDialog(parentDialog) {
+CSearchAnalysisDialog::CSearchAnalysisDialog(
+        const CSwordModuleSearch::Results &results,
+        QWidget *parentDialog)
+        : QDialog(parentDialog)
+{
     initView();
     m_analysis->reset();
-    m_analysis->analyse(modules);
+    m_analysis->analyse(results);
 
     // Set initial width based on the search data, but limit to the
     // width of the desktop
-    int width = (int)( m_analysis->width() + DIALOG_BORDER );
-    int desktopWidth = QApplication::desktop()->screenGeometry(this).width();
-    if (width > desktopWidth)
-        width = desktopWidth;
-    resize(width, DIALOG_HEIGHT);
-
+    int const width = static_cast<int>(m_analysis->width() + DIALOG_BORDER);
+    int const desktopWidth =
+        QApplication::desktop()->screenGeometry(this).width();
+    resize(qMin(width, desktopWidth), DIALOG_HEIGHT);
 }
 
 /** Initializes this dialog. */
@@ -49,7 +52,7 @@ void CSearchAnalysisDialog::initView() {
 
     m_analysis = new CSearchAnalysisScene(this);
     m_analysisView = new CSearchAnalysisView(m_analysis, this);
-////	m_analysisView->show();
+////    m_analysisView->show();
     vboxLayout->addWidget(m_analysisView);
 
     m_buttonBox = new QDialogButtonBox(this);
@@ -57,13 +60,12 @@ void CSearchAnalysisDialog::initView() {
     m_buttonBox->setStandardButtons(QDialogButtonBox::Close);
     m_buttonBox->addButton(QDialogButtonBox::Save);
     //tr("Save as HTML"),
-    util::prepareDialogBox(m_buttonBox);
+    message::prepareDialogBox(m_buttonBox);
     vboxLayout->addWidget(m_buttonBox);
 
-    bool ok = QObject::connect(m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
-    Q_ASSERT(ok);
-    ok = QObject::connect(m_buttonBox, SIGNAL(clicked(QAbstractButton*)), this, SLOT(buttonClicked(QAbstractButton*)));
-    Q_ASSERT(ok);
+    BT_CONNECT(m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    BT_CONNECT(m_buttonBox, SIGNAL(clicked(QAbstractButton *)),
+               this, SLOT(buttonClicked(QAbstractButton *)));
 }
 
 void CSearchAnalysisDialog::buttonClicked(QAbstractButton* button) {
