@@ -1,8 +1,10 @@
 /*********
 *
+* In the name of the Father, and of the Son, and of the Holy Spirit.
+*
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -12,7 +14,7 @@
 
 #include <QDialog>
 
-#include <QObject>
+#include "backend/cswordmodulesearch.h"
 
 
 class CSwordModuleInfo;
@@ -25,20 +27,20 @@ class CSearchAnalysisView;
 class CSearchAnalysisScene;
 
 /**
-	@author The BibleTime team <info@bibletime.info>
+    @author The BibleTime team <info@bibletime.info>
 */
 class CSearchAnalysisDialog : public QDialog {
         Q_OBJECT
     public:
-        CSearchAnalysisDialog(QList<CSwordModuleInfo*> modules, QWidget* parentDialog);
-        ~CSearchAnalysisDialog() {}
+        CSearchAnalysisDialog(const CSwordModuleSearch::Results &results,
+                              QWidget *parentDialog = nullptr);
 
     protected: // Protected methods
         /**
          * Initializes this dialog.
          */
         void initView();
-        void resizeEvent(QResizeEvent* event);
+        void resizeEvent(QResizeEvent* event) override;
 
     private slots:
         void buttonClicked(QAbstractButton* button);
