@@ -1,8 +1,10 @@
 /*********
 *
+* In the name of the Father, and of the Son, and of the Holy Spirit.
+*
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2008 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -18,7 +20,7 @@ namespace Search {
 class CHistoryComboBox : public QComboBox {
         Q_OBJECT
     public:
-        CHistoryComboBox(QWidget* parent = 0);
+        CHistoryComboBox(QWidget* parent = nullptr);
         ~CHistoryComboBox();
         void addToHistory(const QString& item);
         QStringList historyItems() const;
