@@ -1,8 +1,10 @@
 /*********
 *
+* In the name of the Father, and of the Son, and of the Holy Spirit.
+*
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2011 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -10,7 +12,7 @@
 #ifndef CACCELERATORSETTINGS_H
 #define CACCELERATORSETTINGS_H
 
-#include "frontend/bookshelfmanager/btconfigdialog.h"
+#include "btconfigdialog.h"
 
 #include <QPointer>
 #include <QWidget>
@@ -19,24 +21,28 @@
 
 class BtActionCollection;
 class BtShortcutsEditor;
+class CConfigurationDialog;
 class QComboBox;
+class QLabel;
 class QStackedWidget;
 
 /**
-    @author The BibleTime team <info@bibletime.info>
-*/
-class CAcceleratorSettingsPage : public BtConfigPage {
+ * @brief The shortcut settings page.
+ * @author The BibleTime team <info@bibletime.info>
+ */
+class CAcceleratorSettingsPage: public BtConfigDialog::Page {
+
         Q_OBJECT
-    public:
-        CAcceleratorSettingsPage(QWidget *parent = 0);
-        ~CAcceleratorSettingsPage();
+
+    public: /* Methods: */
+
+        CAcceleratorSettingsPage(CConfigurationDialog *parent = nullptr);
+
         void save();
 
-        /** Reimplemented from BtConfigPage. */
-        virtual const QIcon &icon() const;
+    protected: /* Methods: */
 
-        /** Reimplemented from BtConfigPage. */
-        virtual QString header() const;
+        void retranslateUi();
 
     protected slots:
 
@@ -52,13 +58,8 @@ class CAcceleratorSettingsPage : public BtConfigPage {
             QString title;
 
             WindowType() {
-                keyChooser = 0;
-                actionCollection = 0;
-            };
-            WindowType(const QString& newTitle) {
-                title = newTitle;
-                keyChooser = 0;
-                actionCollection = 0;
+                keyChooser = nullptr;
+                actionCollection = nullptr;
             }
         };
 
@@ -74,6 +75,7 @@ class CAcceleratorSettingsPage : public BtConfigPage {
         WindowType m_lexicon;
         WindowType m_book;
 
+        QLabel *m_actionGroupLabel;
         QComboBox* m_typeChooser;
         QStackedWidget* m_keyChooserStack;
 
