@@ -1,8 +1,10 @@
 /*********
 *
+* In the name of the Father, and of the Son, and of the Holy Spirit.
+*
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2009 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -16,9 +18,9 @@
 class CListWidget : public QListWidget {
         Q_OBJECT
     public:
-        CListWidget(QWidget* parent = 0);
-        ~CListWidget();
-        virtual QSize sizeHint () const;
+        CListWidget(QWidget* parent = nullptr);
+
+        QSize sizeHint() const override;
         void setCharWidth(int width);
 };
 
